# MyNN
A pure-Python neural network library based on the amazing
[MyGrad](https://github.com/rsokl/MyGrad).

`mynn` was created as an extension to `mygrad` for rapid prototyping of neural networks with minimal dependencies, a
clean code base with excellent documentation, and as a learning tool.

## Installation Instructions
If you already have MyGrad installed, clone MyNN, navigate to the resulting directory, and
run

``` shell
python setup.py develop
```

If you don't have MyGrad installed, then you can run

``` shell
git clone https://github.com/rsokl/MyGrad.git
cd MyGrad
python setup.py develop
```

Then clone and install this repository.

## Quickstart
Please see the [example notebooks](examples/) for a gentle introduction.
